==> zio-aws-rds_2.12-5.17.129.2-sources.jar: zio/aws/rds/model/UserAuthConfigInfo.scala <==
package zio.aws.rds.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class UserAuthConfigInfo(
    description: scala.Option[String] = None,
    userName: scala.Option[String] = None,
    authScheme: scala.Option[zio.aws.rds.model.AuthScheme] = None,
    secretArn: scala.Option[String] = None,
    iamAuth: scala.Option[zio.aws.rds.model.IAMAuthMode] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.rds.model.UserAuthConfigInfo = {
    import UserAuthConfigInfo.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.rds.model.UserAuthConfigInfo
      .builder()
      .optionallyWith(description.map(value => value: java.lang.String))(
        _.description
      )
      .optionallyWith(userName.map(value => value: java.lang.String))(
        _.userName
      )
      .optionallyWith(authScheme.map(value => value.unwrap))(_.authScheme)
      .optionallyWith(secretArn.map(value => value: java.lang.String))(
        _.secretArn
      )
      .optionallyWith(iamAuth.map(value => value.unwrap))(_.iamAuth)
      .build()
  }
  def asReadOnly: zio.aws.rds.model.UserAuthConfigInfo.ReadOnly =
    zio.aws.rds.model.UserAuthConfigInfo.wrap(buildAwsValue())
}
object UserAuthConfigInfo {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.rds.model.UserAuthConfigInfo
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.rds.model.UserAuthConfigInfo =
      zio.aws.rds.model.UserAuthConfigInfo(
        description.map(value => value),
        userName.map(value => value),
        authScheme.map(value => value),
        secretArn.map(value => value),
        iamAuth.map(value => value)
      )
    def description: scala.Option[String]
    def userName: scala.Option[String]
    def authScheme: scala.Option[zio.aws.rds.model.AuthScheme]
    def secretArn: scala.Option[String]
    def iamAuth: scala.Option[zio.aws.rds.model.IAMAuthMode]
    def getDescription: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("description", description)
    def getUserName: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("userName", userName)
    def getAuthScheme: ZIO[Any, AwsError, zio.aws.rds.model.AuthScheme] =
      AwsError.unwrapOptionField("authScheme", authScheme)
    def getSecretArn: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("secretArn", secretArn)
    def getIamAuth: ZIO[Any, AwsError, zio.aws.rds.model.IAMAuthMode] =
      AwsError.unwrapOptionField("iamAuth", iamAuth)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.rds.model.UserAuthConfigInfo
  ) extends zio.aws.rds.model.UserAuthConfigInfo.ReadOnly {
    override val description: scala.Option[String] =
      scala.Option(impl.description()).map(value => value: String)
    override val userName: scala.Option[String] =
      scala.Option(impl.userName()).map(value => value: String)
    override val authScheme: scala.Option[zio.aws.rds.model.AuthScheme] = scala
      .Option(impl.authScheme())
      .map(value => zio.aws.rds.model.AuthScheme.wrap(value))
    override val secretArn: scala.Option[String] =
      scala.Option(impl.secretArn()).map(value => value: String)
    override val iamAuth: scala.Option[zio.aws.rds.model.IAMAuthMode] = scala
      .Option(impl.iamAuth())
      .map(value => zio.aws.rds.model.IAMAuthMode.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.rds.model.UserAuthConfigInfo
  ): zio.aws.rds.model.UserAuthConfigInfo.ReadOnly = new Wrapper(impl)
}

==> zio-aws-rds_2.12-5.17.183.1-sources.jar: zio/aws/rds/model/UserAuthConfigInfo.scala <==
package zio.aws.rds.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class UserAuthConfigInfo(
    description: Optional[String] = Optional.Absent,
    userName: Optional[String] = Optional.Absent,
    authScheme: Optional[zio.aws.rds.model.AuthScheme] = Optional.Absent,
    secretArn: Optional[String] = Optional.Absent,
    iamAuth: Optional[zio.aws.rds.model.IAMAuthMode] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.rds.model.UserAuthConfigInfo = {
    import UserAuthConfigInfo.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.rds.model.UserAuthConfigInfo
      .builder()
      .optionallyWith(description.map(value => value: java.lang.String))(
        _.description
      )
      .optionallyWith(userName.map(value => value: java.lang.String))(
        _.userName
      )
      .optionallyWith(authScheme.map(value => value.unwrap))(_.authScheme)
      .optionallyWith(secretArn.map(value => value: java.lang.String))(
        _.secretArn
      )
      .optionallyWith(iamAuth.map(value => value.unwrap))(_.iamAuth)
      .build()
  }
  def asReadOnly: zio.aws.rds.model.UserAuthConfigInfo.ReadOnly =
    zio.aws.rds.model.UserAuthConfigInfo.wrap(buildAwsValue())
}
object UserAuthConfigInfo {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.rds.model.UserAuthConfigInfo
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.rds.model.UserAuthConfigInfo =
      zio.aws.rds.model.UserAuthConfigInfo(
        description.map(value => value),
        userName.map(value => value),
        authScheme.map(value => value),
        secretArn.map(value => value),
        iamAuth.map(value => value)
      )
    def description: Optional[String]
    def userName: Optional[String]
    def authScheme: Optional[zio.aws.rds.model.AuthScheme]
    def secretArn: Optional[String]
    def iamAuth: Optional[zio.aws.rds.model.IAMAuthMode]
    def getDescription: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("description", description)
    def getUserName: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("userName", userName)
    def getAuthScheme: ZIO[Any, AwsError, zio.aws.rds.model.AuthScheme] =
      AwsError.unwrapOptionField("authScheme", authScheme)
    def getSecretArn: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("secretArn", secretArn)
    def getIamAuth: ZIO[Any, AwsError, zio.aws.rds.model.IAMAuthMode] =
      AwsError.unwrapOptionField("iamAuth", iamAuth)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.rds.model.UserAuthConfigInfo
  ) extends zio.aws.rds.model.UserAuthConfigInfo.ReadOnly {
    override val description: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.description())
      .map(value => value: String)
    override val userName: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.userName())
      .map(value => value: String)
    override val authScheme: Optional[zio.aws.rds.model.AuthScheme] =
      zio.aws.core.internal
        .optionalFromNullable(impl.authScheme())
        .map(value => zio.aws.rds.model.AuthScheme.wrap(value))
    override val secretArn: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.secretArn())
      .map(value => value: String)
    override val iamAuth: Optional[zio.aws.rds.model.IAMAuthMode] =
      zio.aws.core.internal
        .optionalFromNullable(impl.iamAuth())
        .map(value => zio.aws.rds.model.IAMAuthMode.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.rds.model.UserAuthConfigInfo
  ): zio.aws.rds.model.UserAuthConfigInfo.ReadOnly = new Wrapper(impl)
}
